%% FDI filter plotting
% This file generates the plots for \subsection{Results\Maneuvers} for the
% paper submitted to AIAA SciTech 2015.

%% Limit plotting to specified time interval
limit = find(e.time == 40);

%% Wind gust time marker
man.time1 = [5; 5];
man.time2 = [15; 15];
man.ycoord = [-1e3, 1e3];

%% Fault injection time marker
fault.time = [20; 20];
fault.ycoord = [-1e3, 1e3];

%% Global fault detection markers
t1 = 1:detect.hittime.globalind-1;
t2 = detect.hittime.globalind:numel(e.time);
alwayson = ones(length(t2),1);

%% Plot the error signals for detection
figure;

subplot(321); % beta
hold on;
fm1 = plot(man.time1, [-4, -3.8], 'g-', 'LineWidth', 3);
fm2 = plot(man.time2, [-4, -3.8], 'g-', 'LineWidth', 3);
ffi = plot(fault.time, [-4, -3.8], 'm-', 'LineWidth', 3);
fSIL = plot(SIL_mod.time, SIL_mod.beta*r2d);
set(fSIL, 'LineStyle', '-', 'Color', 'b', 'LineWidth', 1);
fLin = plot(Lin_mod.time_L, Lin_mod.beta_L + Lin_mod.TrimCondition.WindAxesIni(3)*r2d);
set(fLin, 'LineStyle', '--', 'Color', 'r', 'LineWidth', 3);
hold off;
grid on;
ylabel('\beta [deg]', 'FontSize', 14, 'FontWeight', 'bold');
a1 = gca;
set(a1, 'XMinorTick', 'on', 'YMinorTick', 'on', ...
        'XLim', [0 40], 'YLim', [-4 2], ...
        'XTickLabel', [], 'YTick', -4:2:2, 'FontSize', 14, 'FontWeight', 'bold');

subplot(323); % p
hold on;
fm1 = plot(man.time1, [-80, -75], 'g-', 'LineWidth', 3);
fm2 = plot(man.time2, [-80, -75], 'g-', 'LineWidth', 3);
ffi = plot(fault.time, [-80, -75], 'm-', 'LineWidth', 3);
fSIL = plot(SIL_mod.time, SIL_mod.p*r2d);
set(fSIL, 'LineStyle', '-', 'Color', 'b', 'LineWidth', 1);
fLin = plot(Lin_mod.time_L, Lin_mod.p_L);
set(fLin, 'LineStyle', '--', 'Color', 'r', 'LineWidth', 3);
hold off;
grid on;
ylabel('p [deg/s]', 'FontSize', 14, 'FontWeight', 'bold');
a1 = gca;
set(a1, 'XMinorTick', 'on', 'YMinorTick', 'on', ...
        'XLim', [0 40], 'YLim', [-80 40], ...
        'XTickLabel', [], 'YTick', -80:40:40, 'FontSize', 14, 'FontWeight', 'bold');
L1 = legend([fSIL, fLin], 'Off-nominal', 'Nominal', 'Location', 'Best');
set(L1, 'FontSize', 14, 'FontWeight', 'bold');

subplot(325); % r
hold on;
fm1 = plot(man.time1, [-10, -9], 'g-', 'LineWidth', 3);
fm2 = plot(man.time2, [-10, -9], 'g-', 'LineWidth', 3);
ffi = plot(fault.time, [-10, -9], 'm-', 'LineWidth', 3);
fSIL = plot(SIL_mod.time, SIL_mod.r*r2d);
set(fSIL, 'LineStyle', '-', 'Color', 'b', 'LineWidth', 1);
fLin = plot(Lin_mod.time_L, Lin_mod.r_L);
set(fLin, 'LineStyle', '--', 'Color', 'r', 'LineWidth', 3);
hold off;
grid on;
xlabel('Time, t [s]', 'FontSize', 14, 'FontWeight', 'bold');
ylabel('r [deg/s]', 'FontSize', 14, 'FontWeight', 'bold');
a1 = gca;
set(a1, 'XMinorTick', 'on', 'YMinorTick', 'on', ...
        'XLim', [0 40], 'YLim', [-10 10], ...
        'YTick', -10:5:10, 'FontSize', 14, 'FontWeight', 'bold');

subplot(322); % beta
hold on;
fm1 = plot(man.time1, [-4, -3.8], 'g-', 'LineWidth', 3);
fm2 = plot(man.time2, [-4, -3.8], 'g-', 'LineWidth', 3);
ffi = plot(fault.time, [-4, -3.8], 'm-', 'LineWidth', 3);
fr = plot(e.time, e.beta);
set(fr, 'LineStyle', '-', 'Color', 'b', 'LineWidth', 1);
fman = plot(e.time(t1), detect.sustain.beta(t1));
set(fman, 'LineStyle', '-', 'Color', 'g', 'LineWidth', 3);
ffd = plot(e.time(t2), -1.*alwayson);
set(ffd, 'LineStyle', '-', 'Color', 'r', 'LineWidth', 3);
hold off;
grid on;
ylabel('\Delta \beta [deg]', 'FontSize', 14, 'FontWeight', 'bold');
a1 = gca;
set(a1, 'XMinorTick', 'on', 'YMinorTick', 'on', ...
        'XLim', [0 40], 'YLim', [-4 2], ...
        'XTickLabel', [], 'YTick', -4:2:2, 'FontSize', 14, 'FontWeight', 'bold');

subplot(324); % p
hold on;
fm1 = plot(man.time1, [-6, -5.5], 'g-', 'LineWidth', 3);
fm2 = plot(man.time2, [-6, -5.5], 'g-', 'LineWidth', 3);
ffi = plot(fault.time, [-6, -5.5], 'm-', 'LineWidth', 3);
fr = plot(e.time, e.p);
set(fr, 'LineStyle', '-', 'Color', 'b', 'LineWidth', 1);
fman = plot(e.time(t1), detect.sustain.p(t1));
set(fman, 'LineStyle', '-', 'Color', 'g', 'LineWidth', 3);
ffd = plot(e.time(t2), -1.*alwayson);
set(ffd, 'LineStyle', '-', 'Color', 'r', 'LineWidth', 3);
hold off;
grid on;
ylabel('\Delta p [deg/s]', 'FontSize', 14, 'FontWeight', 'bold');
a1 = gca;
set(a1, 'XMinorTick', 'on', 'YMinorTick', 'on', ...
        'XLim', [0 40], 'YLim', [-6 6], ...
        'XTickLabel', [], 'YTick', -6:3:6, 'FontSize', 14, 'FontWeight', 'bold');

subplot(326); % r
hold on;
fm1 = plot(man.time1, [-5, -4.5], 'g-', 'LineWidth', 3);
fm2 = plot(man.time2, [-5, -4.5], 'g-', 'LineWidth', 3);
ffi = plot(fault.time, [-5, -4.5], 'm-', 'LineWidth', 3);
fr = plot(e.time, e.r);
set(fr, 'LineStyle', '-', 'Color', 'b', 'LineWidth', 1);
fman = plot(e.time(t1), detect.sustain.r(t1));
set(fman, 'LineStyle', '-', 'Color', 'g', 'LineWidth', 3);
ffd = plot(e.time(t2), alwayson);
set(ffd, 'LineStyle', '-', 'Color', 'r', 'LineWidth', 3);
hold off;
grid on;
xlabel('Time, t [s]', 'FontSize', 14, 'FontWeight', 'bold');
ylabel('\Delta r [deg/s]', 'FontSize', 14, 'FontWeight', 'bold');
a1 = gca;
set(a1, 'XMinorTick', 'on', 'YMinorTick', 'on', ...
        'XLim', [0 40], 'YLim', [-5 10], ...
        'YTick', -5:5:10, 'FontSize', 14, 'FontWeight', 'bold');
L1 = legend([fr, ffd], 'Residual', 'Fault detection', ...
        'Location', 'Best');
set(L1, 'FontSize', 14, 'FontWeight', 'bold');
