%% File to simulate the nonlinear closed-loop plant to different fault levels
% This file simulates the response of the real aircraft to different fault
% levels in the rudder. Top and bottom rudder faults are simulated from
% -25deg to +25deg. The results are saved to disk so that they may be
% plotted using fault_level.m

%% Clean the slate
clear all, close all, bdclose all, clc

%% Run SIL_sim in a for loop and save the outputs to disk
fault_vec = -25:+25;

% Top rudder faults
for k = 1:numel(fault_vec)
    clearvars -except fault_vec k
    whos
    run ('..\SIL_Sim\setup.m');
    t_rud_fault = fault_vec(k); % set top rudder fault level
    t_rud_inject_time = 5; % set top rudder fault injection time
    b_rud_fault = 0; % set bottom rudder fault level
    b_rud_inject_time = 1000; % set bottom rudder fault injection time
    sim('UAV_SIL'); % simulate with fault injections
    faultname = strrep(num2str(t_rud_fault, '%4.2f'), '.', '_');
    filename = ['simres_SIL_Ft', faultname, '_cz'];
    siminfo = ['SIL_sim. Faulted, t_rud = ', faultname, ...
                ' deg at t = 5s. All commands are zero throughout.'];
    save_to_struct; % save to disk
end

% Bottom rudder faults
for k = 1:numel(fault_vec)
    clearvars -except fault_vec k
    whos
    run ('..\SIL_Sim\setup.m');
    t_rud_fault = 0; % set top rudder fault level
    t_rud_inject_time = 1000; % set top rudder fault injection time
    b_rud_fault = fault_vec(k); % set bottom rudder fault level
    b_rud_inject_time = 5; % set bottom rudder fault injection time
    sim('UAV_SIL'); % simulate with fault injection
    faultname = strrep(num2str(b_rud_fault, '%4.2f'), '.', '_');
    filename = ['simres_SIL_Fb', faultname, '_cz'];
    siminfo = ['SIL_sim. Faulted, b_rud = ', faultname, ...
                ' deg at t = 5s. All commands are zero throughout.'];
    save_to_struct; % save to disk
end
